Measurement Models
==================

.. automodule:: stonesoup.models.measurement
    :no-members:

.. automodule:: stonesoup.models.measurement.base
    :show-inheritance:

Linear
------
.. automodule:: stonesoup.models.measurement.linear
    :show-inheritance:
    :inherited-members:

NonLinear
---------
.. automodule:: stonesoup.models.measurement.nonlinear
    :show-inheritance:
    :inherited-members:
